@@ -568,7 +568,7 @@ def get_Table(client, sid, pid, item):
 def send_Confirm(client,sid,pid,item):
     print
     ask = ""
-    while not ask:
+    while not ask and not client.no_questions:
         try:
             ask = raw_input(item.message+ '(yes/no): ')
         except KeyboardInterrupt:
